<?php

namespace App\Http\Controllers\Admin;

use App\Category;
use App\Question;
use App\Helper\Reply;
use App\GroupQuestion;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use App\QuestionGroupQuestion;
use Illuminate\Routing\Controller;
use Yajra\DataTables\Facades\DataTables;
use App\Http\Requests\StoreGroupQuestion;
use App\Http\Requests\Category\StoreCategory;

class AdminGroupQuestionController extends AdminBaseController
{
    /**
     * Display a listing of the resource.
     * @return Response
     */

    public function __construct()
    {
        parent::__construct();
        $this->pageTitle = 'menu.groupQuestion';
        $this->pageIcon = 'icon-grid';
    }

    public function index()
    {
        return view('admin.question.groupQuestions.index', $this->data);
    }

    /**
     * Show the form for creating a new resource.
     * @return Response
     */
    public function create()
    {
        $this->questions = Question::all();
        return view('admin.question.groupQuestions.create',$this->data);
    }

    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Response
     */
    public function store(StoreGroupQuestion $request)
    {
        $group = new GroupQuestion;
        $group->company_id = company()->id;
        $group->group_question_name = $request->group_question_name;
        $group->save();
         
        $group->questions()->attach($request->question);
        // return Reply::redirect(route('admin.groupquestions.index'), __('messages.createdSuccessfully'));
        return Reply::redirect(route('admin.groupquestions.index'), __('menu.question').' '.__('messages.updatedSuccessfully'));
    }

    /**
     * Show the specified resource.
     * @param int $id
     * @return Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     * @param int $id
     * @return Response
     */
    public function edit($id)
    {
        $this->groupQuestion = GroupQuestion::find($id);
        $this->groupQuestionlist = json_encode($this->groupQuestion->questions->pluck('id')->toArray());
        $this->questions = Question::all();
        return view('admin.question.groupQuestions.edit',$this->data);
    }

    /**
     * Update the specified resource in storage.
     * @param Request $request
     * @param int $id
     * @return Response
     */
    public function update(StoreGroupQuestion $request, $id)
    {
        $groupQuestion = GroupQuestion::findOrFail($id);
        $groupQuestion->company_id = company()->id;
        $groupQuestion->group_question_name = $request->group_question_name;
        $groupQuestion->save();
        $groupQuestion->questions()->sync($request->question);
        return Reply::redirect(route('admin.groupquestions.index'), __('menu.question').' '.__('messages.updatedSuccessfully'));

    }

    /**
     * Remove the specified resource from storage.
     * @param int $id
     * @return Response
     */
    public function destroy($id)
    {
        GroupQuestion::destroy($id);
        return Reply::success(__('messages.recordDeleted'));

    }

    public function data()
    {
        $groupQuestion = GroupQuestion::all();
        return DataTables::of($groupQuestion)
        ->addColumn('action', function ($row) {
            // dd($row);
            $action = '';

                $action.= '<a href="' . route('admin.groupquestions.edit', [$row->id]) . '" class="btn btn-primary btn-circle"
                  data-toggle="tooltip" onclick="this.blur()" data-original-title="'.__('app.edit').'"><i class="fa fa-pencil" aria-hidden="true"></i></a>';

                $action.= ' <a href="javascript:;" class="btn btn-danger btn-circle sa-params"
                  data-toggle="tooltip" onclick="this.blur()" data-row-id="' . $row->id . '" data-original-title="'.__('app.delete').'"><i class="fa fa-times" aria-hidden="true"></i></a>';
            return $action;
        })
        ->editColumn('group_question_name', function ($row) {
            return ucfirst($row->group_question_name);
        })
        ->rawColumns(['action'])
        ->addIndexColumn()
        ->make(true);
    }

}
