<?php

namespace App\Http\Controllers\SaasFront;

use App\Job;
use App\Role;
use App\User;
use App\Company;
use App\JobType;
use App\Package;
use Carbon\Carbon;
use App\FooterMenu;
use App\JobCategory;
use App\JobLocation;
use App\Helper\Reply;
use App\ThemeSetting;
use App\FooterSetting;
use App\GlobalSetting;
use App\ClientFeedback;
use App\FrontCmsHeader;
use App\JobJobLocation;
use App\WorkExperience;
use App\LanguageSetting;
use App\LinkedInSetting;
use App\FrontIconFeature;
use App\Mail\ContactMail;
use App\FrontImageFeature;
use App\Traits\SmtpSettings;
use Illuminate\Http\Request;
use App\Http\Requests\ContactForm;
use Illuminate\Support\Facades\DB;
use App\Http\Requests\RegisterForm;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Session;
use App\Notifications\EmailVerification;
use App\Notifications\NewCompanyRegister;
use Illuminate\Support\Facades\Notification;
use App\Notifications\EmailVerificationSuccess;
use App\Http\Controllers\Front\FrontJobsController;

class SaasFrontController extends SaasFrontBaseController
{
    use SmtpSettings;
    public function __construct()
    {
        parent::__construct();
        $this->defaultFrontDetail = FooterSetting::first();
        $this->pageTitle = 'app.register';
    }

    public function index()
    {
        if ($this->global->setup_homepage == 1) {
            return response(file_get_contents($this->global->custom_homepage_url));
        }
        if(module_enabled('Subdomain')){
            $company = Company::where('sub_domain', request()->getHost())->first();
            if($company){
                $job = new FrontJobsController();
                return  $job->jobOpenings();
            }
        }
        $imageFeaturesCount = FrontImageFeature::select('id', 'language_settings_id')->where('language_settings_id', $this->localeLanguage->id)->count();
        $iconFeaturesCount = FrontIconFeature::select('id', 'language_settings_id')->where('language_settings_id', $this->localeLanguage->id)->count();
        $feedbackCount = ClientFeedback::select('id', 'language_settings_id')->where('language_settings_id', $this->localeLanguage->id)->count();
        $footerMenuCount = FooterMenu::select('id', 'language_settings_id')->where('language_settings_id', $this->localeLanguage->id)->count();
        $footerSettingsCount = FooterSetting::select('id', 'language_settings_id')->where('language_settings_id', $this->localeLanguage->id)->count();

        $this->imageFeatures = FrontImageFeature::where('language_settings_id', $imageFeaturesCount > 0 ? $this->localeLanguage->id : $this->englishLangId)->get();
        $this->iconFeatures = FrontIconFeature::where('language_settings_id', $iconFeaturesCount > 0 ? $this->localeLanguage->id : $this->englishLangId)->get();
        $this->feedbacks = ClientFeedback::where('language_settings_id', $feedbackCount > 0 ? $this->localeLanguage->id : $this->englishLangId)->get();
        $this->packages = Package::where('is_trial', 0)->where('status', 1)->where('is_private',0)->where('default', '!=', 'yes')->get();
        $this->frontDetail = FooterSetting::where('language_settings_id', $footerSettingsCount > 0 ? $this->localeLanguage->id : $this->englishLangId)->first();
        $this->footerSettings = FooterMenu::where('language_settings_id', $footerMenuCount > 0 ? $this->localeLanguage->id : $this->englishLangId)->get();

        $currentDate = Carbon::now()->format('Y-m-d');

            
        $this->featuredCompanies = Company::select('companies.*')->where('companies.status', 'active')
        ->join('company_packages', 'company_packages.id', 'companies.package_id')
        ->join('packages', 'company_packages.package_id', 'packages.id')
            ->where(function ($query) use($currentDate) {
                $query->whereNull('featured_start_date')
                    ->orWhere(DB::raw('DATE(`featured_start_date`)'), '<=', $currentDate);
            })
            ->where(function ($query) use($currentDate) {
                    $query->whereNull('featured_end_date')
                        ->orWhere(DB::raw('DATE(`featured_end_date`)'), '>=', $currentDate);
                })
                ->where(function ($query) use($currentDate) {
                    $query->whereNull('licence_expire_on')
                        ->orWhere(DB::raw('DATE(`licence_expire_on`)'), '>=', $currentDate);
                })
                ->where(function ($query) use($currentDate) {
                    $query->where(DB::raw('DATE(company_packages.end_date)'), '>=', DB::raw('CURDATE()'))
                    ->orWhereNotNull('company_packages.end_date');
                })
            ->where('featured', 1)->get();
        return view('saas-front.index', $this->data);
    }

    public function submitContact(ContactForm $request) {
        $superAdmin = User::whereNull('company_id')->first();
        $this->setMailConfigs();
        Mail::to($superAdmin->email)->send(new ContactMail($request));
        return Reply::dataOnly(['status' => 'success']);
    }

    public function companyRegister(RegisterForm $request) {

        $company = new Company();
        try {
            $company->company_name = $request->company_name;
            $company->career_page_link = str_slug($request->career_page_link, '-');
            $company->job_opening_text = 'Welcome!';
            $company->job_opening_title = 'We want people to thrive. We believe you do your best work when you feel your best.';
            $company->timezone = 'Asia/Kolkata';

            if (module_enabled('Subdomain')){
                $company->sub_domain = $request->sub_domain;
            }

            $company->save();

            $user = new User();
            $user->company_id = $company->id;
            $user->name = $request->full_name;
            $user->email = $request->email;
            $user->password = bcrypt($request->password);
            $user->email_verification_code = str_random(40);
            $user->status = 'inactive';
            $user->save();

            //assign admin role to default user
            $role = Role::where('company_id', $company->id)->first();
            $user->roles()->attach($role->id);

            $user->notify(new EmailVerification($user));

            $superAdmin = User::whereNull('company_id')->get();
            Notification::send($superAdmin, new NewCompanyRegister($company));
            
        } catch (\Swift_TransportException $e) {
            DB::rollback();
            return Reply::error('Please contact administrator to set SMTP details to add company', 'smtp_error');
        } catch (\Exception $e) {
            DB::rollback();
            return Reply::error('Some error occurred when inserting the data. Please try again or contact support');
        }
        $registration = GlobalSetting::first();

        return Reply::dataOnly(['status' => 'success']);

    }

    public function getEmailVerification($code)
    {

        $this->pageTitle = 'modules.saasFront.emailVerification';
        $this->setting = GlobalSetting::first();
        $this->headerData = FrontCmsHeader::first();
        $this->frontTheme = ThemeSetting::whereNull('company_id')->first();

        $user = User::where('email_verification_code', $code)->whereNotNull('email_verification_code')->first();

        if ($user) {
            $user->status = 'active';
            $user->email_verification_code = '';
            $user->save();

            $user->notify(new EmailVerificationSuccess($user));

            $this->messsage = __('messages.emailVerifySuccess');
            $this->class = 'success';
            return view('saas-front.email-verification', $this->data);


        } else {

            $this->messsage = __('messages.emailVerifyFail');
            $this->class = 'error';
            return view('saas-front.email-verification', $this->data);
        }

    }

    public function changeLanguage($code)
    {
        $language = LanguageSetting::where('language_code', $code)->first();

        if (!$language) {
            return Reply::error('invalid language code');
        }

        return response(Reply::success(__('messages.languageChangedSuccessfully')))->cookie('language_code', $code);
    }

    public function page($slug = null)
    {
        $this->footerMenu = FooterMenu::where('slug', $slug)->with('seo_details')->first();
        $this->footerSettings = FooterMenu::all();
        $this->frontDetail = FooterSetting::first();

        return view('saas-front.page', $this->data);
    }

    public function careerPage(){
        $this->jobLocations = JobJobLocation::select('job_job_locations.*')->with(['saasFrontLocation', 'saasFrontJob'])
        ->where('job_job_locations.id', '>', '0')
        ->join('jobs', 'jobs.id', 'job_job_locations.job_id')
        ->join('job_locations', function ($join) {
            $join->on('job_locations.id', '=', 'job_job_locations.location_id');
        })
        ->where(function ($query) {
            $query->whereNull('jobs.end_date')
                ->orWhereDate('jobs.end_date', '>=', Carbon::now());
        })
        ->where('jobs.status', 'active')
        ->paginate(4);
        $this->locations = JobLocation::all();
        $this->jobTypes = JobType::all();
        $this->jobCategories = JobCategory::all();
        $this->workExperiences = WorkExperience::all();
        $this->footerSettings = FooterMenu::all();
        $this->frontDetail = FooterSetting::first();
        return view('saas-front.career', $this->data);
    }

    public function getJobData(Request $request)
    {      
            
        $workExperience = $request->workExperience;
        $workExperience = explode(',',  $workExperience);
      
        if($request->ajax())
        {
        $jobLocations = JobJobLocation::select('job_job_locations.id as id', 'jobs.id as job_id', 'job_locations.id as location_id')->with(['saasFrontLocation', 'saasFrontJob'])
        ->join('job_locations', function ($join) {
            $join->on('job_locations.id', '=', 'job_job_locations.location_id');
                 
        })
        ->join('jobs', 'jobs.id', 'job_job_locations.job_id')
        ->where('jobs.status', 'active');
       if($request->location != "all" && $request->location != ''){
        $jobLocations = $jobLocations->where('job_locations.id', $request->location);
       }

       if($request->jobType != "all" && $request->jobType != ''){
        $jobLocations = $jobLocations->where('jobs.job_type_id', $request->jobType);

       }
       if($request->category != "all" && $request->category != ''){
        $jobLocations = $jobLocations->where('jobs.category_id', $request->category);
       }

       if($request->workExperience != "all" && $request->workExperience != '' && $request->workExperience != 'undefined'){
        $jobLocations = $jobLocations->whereIn('jobs.work_experience_id', $workExperience);
       }
       $this->jobLocations = $jobLocations->paginate(4);
       
       
        $view =  view('saas-front.more-jobs', $this->data)->render();
        return Reply::dataOnly(['view' => $view]);
    }

    }

  
}
