<?php

namespace App\Http\Controllers\SuperAdmin;

use App\User;
use App\Company;
use App\Package;
use App\Helper\Reply;
use App\GlobalSetting;
use App\CompanyPackage;
use App\CurrentPackage;
use App\OfflineInvoice;
use App\OfflinePlanChange;
use Illuminate\Http\Request;
use Illuminate\Support\Carbon;
use Yajra\DataTables\Facades\DataTables;
use Illuminate\Support\Facades\Notification;
use App\Notifications\OfflinePackageChangeReject;
use App\Notifications\OfflinePackageChangeVerify;

class OfflinePlanChangeController extends SuperAdminBaseController
{
    public function __construct()
    {
        parent::__construct();
        $this->pageTitle = 'Offline Request';
        $this->pageIcon = 'ti-user';
    }

    public function index(){
        $this->global = GlobalSetting::first();
        $this->totalRequest = OfflinePlanChange::count();
        return view('super-admin.offline-plan-change.index', $this->data);
    }

    public function data(){
        $users = OfflinePlanChange::with('company', 'package', 'offline_method');
        return DataTables::of($users)
        ->addColumn('action', function($row) {
            $string = '';
            if($row->status == 'pending') {
                $string .= '<a href="javascript:;" onclick="accept('.$row->id.')" class="btn btn-info btn-circle"
                  data-toggle="tooltip" onclick="this.blur()" data-original-title="Verify"><i class="fa fa-check" aria-hidden="true"></i></a>
                  <a href="javascript:;" onclick="reject('.$row->id.')" class="btn btn-danger btn-circle"
                  data-toggle="tooltip" onclick="this.blur()" data-original-title="Reject"><i class="fa fa-remove" aria-hidden="true"></i></a>';

            }
            
            $string .= ' <a href="'.$row->file.'" target="_blank" class="btn btn-default btn-circle m-l-5"
                  data-toggle="tooltip" onclick="this.blur()" data-original-title="View File"><i class="fa fa-eye" aria-hidden="true"></i></a>';

            return $string;
        })
        ->editColumn(
            'status',
            function ($row) {
                $status = ['pending' => 'warning', 'verified' => 'success', 'rejected' => 'danger'];
                return '<label class="badge bg-'.$status[$row->status].'">'.ucwords($row->status).'</label>';

            }
        )
        ->rawColumns(['name', 'action', 'status', 'file_name'])
        ->make(true);        

    }
    
    public function verify(Request $request)
    {
        $offlinePlanChnage = OfflinePlanChange::findOrFail($request->id);
        $package = Package::find($offlinePlanChnage->package_id);
        $invoice = OfflineInvoice::findOrFail($offlinePlanChnage->invoice_id);
        $company = Company::find($offlinePlanChnage->company_id);
        $companyPackage = CompanyPackage::where('status', 'active')->where('company_id', $company->id)->update(['status' => 'inactive']);
       
       
        $company->package_id = $offlinePlanChnage->package_id;
        $company->package_type = $offlinePlanChnage->package_type;
        $company->save();

            $companyPackage = new CompanyPackage();
            $companyPackage->company_id = $company->id;
            $companyPackage->package_id = $offlinePlanChnage->package_id;
            $companyPackage->currency_symbol = $this->global->currency->currency_symbol;
            $companyPackage->package_name = $package->name;
            $companyPackage->monthly_price = $package->monthly_price;
            $companyPackage->annual_price = $package->annual_price;
            $companyPackage->package_type = $offlinePlanChnage->package_type;
            $companyPackage->offline_invoice_id = $invoice->offline_method_id;
            $companyPackage->start_date = Carbon::now()->format('Y-m-d');
            $companyPackage->end_date = $offlinePlanChnage->package_type == 'monthly' ? Carbon::now()->addMonth()->format('Y-m-d') : Carbon::now()->addYear()->format('Y-m-d');
            $companyPackage->save();

       
        

        $invoice->status = 'paid';
        $invoice->save();

        $offlinePlanChnage->status = 'verified';
        $offlinePlanChnage->save();


        $admins = $users = User::withoutGlobalScope('company')
            ->join('role_user', 'role_user.user_id', '=', 'users.id')
            ->join('roles', 'roles.id', '=', 'role_user.role_id')
            ->select('users.id', 'users.name', 'users.email')
            ->where('roles.name', 'admin')
            ->where('users.company_id', $offlinePlanChnage->company_id)
            ->get();
        Notification::send($admins, new OfflinePackageChangeVerify($offlinePlanChnage));

        return Reply::redirect(route('superadmin.offline-plan.index'),'Request successfully verified');
    }

    public function reject(Request $request)
    {
        $offlinePlanChnage = OfflinePlanChange::findOrFail($request->id);
        $offlinePlanChnage->status = 'rejected';
        $offlinePlanChnage->save();

        $admins = $users = User::withoutGlobalScope('company')
        ->join('role_user', 'role_user.user_id', '=', 'users.id')
        ->join('roles', 'roles.id', '=', 'role_user.role_id')
        ->select('users.id', 'users.name', 'users.email')
        ->where('roles.name', 'admin')
        ->where('users.company_id', $offlinePlanChnage->company_id)
        ->get();
        
        Notification::send($admins, new OfflinePackageChangeReject($offlinePlanChnage));

        return Reply::redirect(route('superadmin.offline-plan.index'),'Request successfully rejected');
    }

}
