<?php

namespace App\Http\Controllers\SuperAdmin;

use App\Job;
use App\Role;
use App\User;
use App\Skill;
use App\Company;
use App\Package;
use Carbon\Carbon;
use App\JobCompany;
use App\JobLocation;
use App\Helper\Files;
use App\Helper\Reply;
use App\CompanyPackage;
use App\JobApplication;
use App\JobJobLocation;
use App\ApplicationStatus;
use Illuminate\Http\Request;
use App\JobApplicationAnswer;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use App\Notifications\NewPackageAssign;
use Yajra\DataTables\Facades\DataTables;
use App\Http\Requests\Company\StoreCompany;
use App\Http\Requests\Company\UpdatePakage;
use App\Http\Requests\Company\UpdateCompany;
use Illuminate\Support\Facades\Notification;

class SuperAdminCompanyController extends SuperAdminBaseController
{

    public function __construct()
    {
        parent::__construct();
        $this->pageTitle = 'menu.companies';
        $this->pageIcon = 'icon-film';
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $this->status = request()->status;
        $this->totalCompanies = Company::withoutGlobalScope('company')->count();
        $this->activeCompanies = Company::withoutGlobalScope('company')->where('status', 'active')->count();
        $this->inactiveCompanies = Company::where('status', 'inactive')->count();
        return view('super-admin.company.index', $this->data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('super-admin.company.create', $this->data);
    }

    /**
     * @param StoreCompany $request
     * @return array
     */
    public function store(StoreCompany $request)
    {
        $setting = new Company();
        $setting->company_name        = $request->input('company_name');
        $setting->career_page_link    = str_slug($request->input('company_name'), '-');
        $setting->company_email       = $request->input('company_email');
        $setting->company_phone       = $request->input('company_phone');
        $setting->website             = $request->input('website');
        $setting->address             = $request->input('address');
        $setting->show_in_frontend    = $request->input('show_in_frontend');
        $setting->job_opening_text    = 'Welcome!';
        $setting->job_opening_title   = 'We want people to thrive. We believe you do your best work when you feel your best.';
        $setting->featured_start_date = Carbon::parse($request->start_date)->format('Y-m-d');
        $setting->featured_end_date   = Carbon::parse($request->end_date)->format('Y-m-d');
        $setting->featured            = ($request->featured == 'yes') ? 1 : 0;
        $setting->timezone            = 'Asia/Kolkata';
        if ($request->hasFile('logo')) {
            $setting->logo = Files::upload($request->logo,'company-logo');
        }
        if(module_enabled('Subdomain')){
            $setting->sub_domain = $request->sub_domain;
        }
        $setting->save();

        $user = new User();
        $user->company_id = $setting->id;
        $user->name = $request->full_name;
        $user->email = $request->email;
        $user->password = bcrypt($request->password);
        $user->save();

        //assign admin role to default user
        $role = Role::where('company_id', $setting->id)->first();
        $user->roles()->attach($role->id);

        return Reply::redirect(route('superadmin.company.index'), __('menu.companies') . ' ' . __('messages.createdSuccessfully'));
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $this->company = Company::withoutGlobalScope('company')->findOrFail($id);
        $this->companyPackage = CompanyPackage::activePackage($id);
      
        $tab = request('tab');
        
        switch ($tab) {
        case 'jobs':
            $this->jobCompany = JobCompany::withoutGlobalScope('company')->where('company_id', $id)->get();
            $this->view = 'super-admin.company.job';
                break;
        case 'applications':
            $this->boardColumns = ApplicationStatus::where('company_id', $id)->get();
            $this->locations = JobLocation::where('company_id', $id)->get();
            $this->jobs = Job::where('company_id', $id)->get();
            $this->view = 'super-admin.company.application';
                break;
        default:    
            $this->view = 'super-admin.company.profile';
                break;
        }


        if (request()->ajax()) {
            $html = view($this->view, $this->data)->render();
            return Reply::dataOnly(['status' => 'success', 'html' => $html, 'title' => $this->pageTitle]);
        }

        ($tab == '') ? $this->activeTab = 'profile' : $this->activeTab = $tab;

        

        return view('super-admin.company.show', $this->data);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $this->company = Company::withoutGlobalScope('company')->findOrFail($id);
        return view('super-admin.company.edit', $this->data);
    }

    /**
     * @param UpdateCompany $request
     * @param $id
     * @return array
     */
    public function update(UpdateCompany $request, $id)
    {
        $setting = Company::withoutGlobalScope('company')->findOrFail($id);

        $setting->company_name        = $request->input('company_name');
        $setting->company_email       = $request->input('company_email');
        $setting->company_phone       = $request->input('company_phone');
        $setting->website             = $request->input('website');
        $setting->address             = $request->input('address');
        $setting->show_in_frontend    = $request->input('show_in_frontend');
        $setting->featured_start_date = Carbon::parse($request->start_date)->format('Y-m-d');
        $setting->featured_end_date   = Carbon::parse($request->end_date)->format('Y-m-d');
        $setting->featured            = ($request->featured == 'yes') ? 1 : 0;

        if(module_enabled('Subdomain')){
            $setting->sub_domain = $request->sub_domain;
        }
        //update company's jobs status
        if ($setting->status != $request->input('status')) {
            Job::where('company_id', $id)->update(['status' => $request->status]);
        }

        $setting->status = $request->input('status');

        if ($request->logo_delete == 'yes') {
            Files::deleteFile($setting->logo,'global-logo');
            $setting->logo = null;
        }

        if ($request->hasFile('logo')) {
            $setting->logo = Files::uploadLocalOrS3($request->logo,'company-logo');
        }

        $setting->save();

        return Reply::redirect(route('superadmin.company.index'), __('menu.companies') . ' ' . __('messages.updatedSuccessfully'));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {

        $company = Company::withoutGlobalScope('company')->where('id', $id)->first();
        Files::deleteFile($company->logo, 'company-logo');
        $company->delete();

        return Reply::success(__('messages.recordDeleted'));
    }

    public function data()
    {
        $categories = Company::with('package')
        ->leftJoin('company_packages', 'company_packages.id','companies.package_id')
        ->select('companies.*', 'company_packages.end_date')
        ->withoutGlobalScope('company');
        
        if (request()->has('status') && !is_null(request()->status) && request()->status != 'pending' && request()->status != 'front_pending') {
            $categories->where('companies.status', request()->status);  
        }
        elseif(request()->has('status') && !is_null(request()->status) && request()->status == 'pending'){
        
            $categories->whereNotNull('licence_expire_on');
            $categories->whereRaw('DATE(licence_expire_on) < ?', [Carbon::now()->format('Y-m-d')]);

        }
        
        elseif(request()->has('status') && !is_null(request()->status) && request()->status == 'front_pending'){
            
            $categories->whereRaw('DATE(company_packages.end_date) < ?', [Carbon::now()->format('Y-m-d')]);

        }

        return DataTables::of($categories)

            ->addColumn('action', function ($row) {
                $action = '';

                $action .= '<a href="' . route('superadmin.company.show', [$row->id]) . '" class="btn btn-dark btn-circle"
                    data-toggle="tooltip" onclick="this.blur()" data-original-title="' . __('app.view') . '"><i class="fa fa-search" aria-hidden="true"></i></a>';

                $action .= ' <a href="' . route('superadmin.company.edit', [$row->id]) . '" class="btn btn-primary btn-circle" data-toggle="tooltip" onclick="this.blur()" data-original-title="' . __('app.edit') . '"><i class="fa fa-pencil" aria-hidden="true"></i></a>';
                
                if(module_enabled('Subdomain')) {
                    $action .= ' <a href="javascript:;" class="btn btn-success btn-circle domain-params"
                      data-toggle="tooltip" onclick="this.blur()" data-company-id="' . $row->id . '" data-company-url="' . request()->getScheme().'//'.$row->sub_domain . '" data-original-title="Domain Notify to company admins"><i class="fa fa-bell" aria-hidden="true"></i></a>';
                }
                $action .= ' <a href="javascript:;" class="btn btn-danger btn-circle sa-params"
                    data-toggle="tooltip" onclick="this.blur()" data-row-id="' . $row->id . '" data-original-title="' . __('app.delete') . '"><i class="fa fa-times" aria-hidden="true"></i></a>';
                return $action;
            })
            ->editColumn('status', function ($row) {
                if ($row->status == 'active') {
                    $status = '<label class="badge bg-success">' . __('app.active') . '</label>';


                    return $status;
                }
                if ($row->status == 'inactive') {
                    return '<label class="badge bg-danger">' . __('app.inactive') . '</label>';
                }
            })

            ->editColumn('logo', function ($row) {
                return '<img src="' . $row->logo_url . '" height="80" />';
            })
            ->editColumn('company_name', function ($row) {
                return '<a href="' . route("superadmin.company.show", [$row->id]) . '">' . ucfirst($row->company_name) . '</a>';
            })
            ->editColumn('package_id', function ($row) {
                $package = ucfirst($row->package->name);

                if (!$row->package->is_trial && $row->package->default != 'yes') {
                    $package .= '<br><small>[' . __('app.' . $row->package_type) . ']</small>';
                }

                if (!is_null($row->licence_expire_on) && $row->licence_expire_on->isPast()) {
                    $package .= '<br> <small class="text-danger">' . __("modules.subscription.packageExpired") . '</small>';
                }
                return $package;
            })
            ->editColumn('sub_domain', function ($row) {
                return '<a href="http://' . $row->sub_domain . '" target="_blank">' . $row->sub_domain . '</a>';
            })
            ->addIndexColumn()
            ->rawColumns(['logo', 'action', 'status', 'package_id', 'company_name','sub_domain'])
            ->make(true);
    }

    public function changePackage($companyId) {
        $this->packages = Package::where('is_trial', 0)->active()->get();
        $this->company = Company::withoutGlobalScope('company')->findOrFail($companyId);

        return view('super-admin.company.change_package_modal', $this->data);
    }

    public function updateCompanyPackage(UpdatePakage $request, $companyId) {
       
        CompanyPackage::where('company_id', $companyId)
        ->update(['status' => 'inactive', 'end_date' => Carbon::now()->format('Y-m-d')]);
        
        $package = Package::find($request->package);

        $company = Company::withoutGlobalScope('company')->findOrFail($companyId);
        $company->package_id = $request->package;
        $companyPackages = new CompanyPackage();
        $companyPackages->package_id = $request->package;
        $companyPackages->company_id = $companyId;
        $companyPackages->currency_symbol = $this->global->currency->currency_symbol;
        $companyPackages->package_name = $package->name;
        $companyPackages->monthly_price = $package->monthly_price;
        $companyPackages->annual_price = $package->annual_price;
        $admins = $users = User::withoutGlobalScope('company')
            ->join('role_user', 'role_user.user_id', '=', 'users.id')
            ->join('roles', 'roles.id', '=', 'role_user.role_id')
            ->select('users.id', 'users.name', 'users.email')
            ->where('roles.name', 'admin')
            ->where('users.company_id', $companyPackages->company_id)
            ->get();
        $companyPackages->start_date = Carbon::now()->format('Y-m-d');
      
        if ($request->package_type) {
            
            $companyPackages->package_type = 'annual';
            $companyPackages->end_date = Carbon::now()->addYear()->format('Y-m-d');
            
            $company->package_type = 'annual';
            $company->licence_expire_on = Carbon::now()->addYear()->format('Y-m-d');

        } else {
            $companyPackages->package_type = 'monthly';
            $companyPackages->end_date = Carbon::now()->addMonth()->format('Y-m-d');
            
            $company->package_type = 'monthly';
            $company->licence_expire_on = Carbon::now()->addMonth()->format('Y-m-d');
        }
        
        $companyPackages->status = 'active';

        if($request->sendMail){
            Notification::send($admins, new NewPackageAssign( $companyPackages));
        }
        
        $companyPackages->save();
       
        $company->save();

        return Reply::success(__('messages.updatedSuccessfully'));

    }

    public function loginAsCompany($companyId)
    {
        $admin = User::frontAllAdmins($companyId)->first();

        Auth::logout();

        Auth::loginUsingId($admin->id);

        return Reply::success(__('messages.successfullyLoginAsCompany'));
    }

    public function jobData()
    {
       $jobs = JobJobLocation::select('job_job_locations.*')->with(['location', 'job'])->where('job_job_locations.id', '>', '0')
        ->join('jobs', 'jobs.id', 'job_job_locations.job_id')
        ->join('job_locations', function ($join) {
            $join->on('job_locations.id', '=', 'job_job_locations.location_id')
                 ->where('job_locations.company_id',  request('company_id'));
        });
       
        if (\request('filter_status') != "") {
            $jobs->where('jobs.status', \request('filter_status'));
        }
        if (\request('job_company') != "") {
            $jobs->where('job_company_id', \request('job_company'));
        }
        
        $jobs->get();

        return DataTables::of($jobs)
       
        ->editColumn('title', function ($row) {
            return '<a href="javascript:;" class="show-detail" data-widget="control-sidebar" data-slide="true" data-row-id="' . $row->job->id . '">' . ucwords($row->job->title) . '</a>';
        })

        ->editColumn('job_company_id', function ($row) {
            return ucfirst($row->job->jobCompanySaas->company_name);
        })

        ->editColumn('location_id', function ($row) {
            return ucfirst($row->location->location) . ' (' . $row->location->country->country_code . ')';
        })
        ->editColumn('start_date', function ($row) {
            return $row->job->start_date->format('d M, Y');
        })
        ->editColumn('end_date', function ($row) {
            return $row->job->end_date ? $row->job->end_date->format('d M, Y') : '--';
        })
        ->editColumn('status', function ($row) {
            if ($row->job->status == 'active') {
                return '<label class="badge bg-success">' . __('app.active') . '</label>';
            }
            if ($row->job->status == 'inactive') {
                return '<label class="badge bg-danger">' . __('app.inactive') . '</label>';
            }
            if ($row->job->status == 'expired') {
                return '<label class="badge" style="background: #FF8C00;">' . __('app.expired') . '</label>';
            }
        })
        ->rawColumns(['title','status', 'action'])
        ->addIndexColumn()
        ->make(true);

    }

    public function jobapplicationData(Request $request)
    {
        
        $jobApplications = JobApplication::withoutGlobalScope('company')->where('company_id', $request->company_id)->select('id', 'job_id', 'status_id', 'full_name', 'skills','location_id')
            ->with(['location',
                'job.skills',
                'status:id,status,color'
            ]);
       
        // Filter by status
        if ($request->status != 'all' && $request->status != '') {
            $jobApplications = $jobApplications->where('status_id', $request->status);
        }
        
        // Filter By jobs
        if ($request->jobs != 'all' && $request->jobs != '') {
            $jobApplications = $jobApplications->where('job_id', $request->jobs);
        }

       
        
        // Filter by location
        if ($request->location != 'all' && $request->location != '') {
            $jobApplications = $jobApplications->where('location_id', $request->location); 
        }

        // Filter by StartDate
        if ($request->startDate != null && $request->startDate != '') {
            $jobApplications = $jobApplications->whereDate('created_at', '>=', $request->startDate);
        }

        // Filter by EndDate
        if ($request->endDate != null && $request->endDate != '') {
            $jobApplications = $jobApplications->whereDate('created_at', '<=', $request->endDate);
        }

        $jobApplications = $jobApplications->get();

        return DataTables::of($jobApplications)
            
            ->editColumn('full_name', function ($row) {
                return '<a href="javascript:;" class="show-detail" data-widget="control-sidebar" data-slide="true" data-row-id="' . $row->id . '">' . ucwords($row->full_name) . '</a>';
            })
            ->editColumn('title', function ($row) {
                return ucfirst($row->job->title);
            })
            ->editColumn('location', function ($row) {
                return ucwords($row->location->location);
            })
            ->editColumn('status', function ($row) {
                return '<span>' . ucwords($row->status->status) .'</span>
                 <span class="badge badge-pill badge-primary text-white" style= "margin-bottom: -3px; height: 15px; background:' . $row->status->color . '"> </span>';
                //return ucwords($row->status->status);
            })
            ->rawColumns(['action', 'full_name','status'])
            ->addIndexColumn()
            ->make(true);
    }

    public function jobApplicationShow($id)
    {
        
        $this->application = JobApplication::withoutGlobalScope('company')->with(['schedule', 'status', 'schedule.employee', 'schedule.comments.user'])->find($id);
       
        $this->timezone = Company::select('id', 'timezone')->first()->timezone;
        
        $this->skills = Skill::select('id', 'name')->get();
        
        $this->answers = JobApplicationAnswer::with(['question'])
            ->where('job_id', $this->application->job_id)
            ->where('job_application_id', $this->application->id)
            ->get();
            
        $view = view('super-admin.company.jobapplication_show', $this->data)->render();
        return Reply::dataOnly(['status' => 'success', 'view' => $view]);
    }

    public function jobShow($id)
    {
        $this->jobs = Job::withoutGlobalScope('company')->with(['jobLocation', 'jobCompanySaas', 'workExperience', 'jobType', 'category'])->find($id);

        $view = view('super-admin.company.job_show', $this->data)->render();
        return Reply::dataOnly(['status' => 'success', 'view' => $view]);

    }


}
