<?php

namespace App\Http\Controllers\Admin;

use App\Helper\Files;
use App\Helper\Reply;
use App\ApplicationSetting;
use Illuminate\Support\Arr;
use Illuminate\Http\Request;

class ApplicationSettingsController extends AdminBaseController
{

    public function __construct()
    {
        parent::__construct();
        $this->pageTitle = 'menu.applicationFormSettings';
        $this->pageIcon = 'icon-settings';
        $this->middleware(function ($request, $next) {
            $this->setting = ApplicationSetting::first();
            return $next($request);
        });

    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        abort_if(! $this->user->cans('manage_settings'), 403);
        $this->timezones = \DateTimeZone::listIdentifiers(\DateTimeZone::ALL);
        $this->settings = ApplicationSetting::where('company_id', company()->id)->first();
        if(!$this->setting){
            abort(404);
        }

        return view('admin.application-setting.index', $this->data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $result = $this->setting;
        return $result;
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        abort_if(! $this->user->cans('manage_settings'), 403);
        $mailSetting = [];
        foreach ($this->setting->mail_setting as $id => $setting) {
            $setting['status'] = false;
            if ($request->has('checkBoardColumn') && in_array($id, $request->checkBoardColumn)) {
                $setting['status'] = true;
            }
            $mailSetting = Arr::add($mailSetting, $id, $setting);
        }

        $this->setting->legal_term = $request->input('legal_term');
        $this->setting->mail_setting = $mailSetting;
        $this->setting->hide_language = $request->has('hide_language') && $request->input('hide_language') == 'on' ? 1 : 0;
        $this->setting->job_alert_status = $request->has('job_alert_status') && $request->input('job_alert_status') == 'on' ? 1 : 0;

        if ($request->favicon_delete == 'yes') {
            Files::deleteFile($this->setting->favicon, 'favicon');
            $this->setting->favicon = null;
        }

        if ($request->hasFile('favicon')) {
            Files::deleteFile($this->setting->favicon, 'favicon');
            $this->setting->favicon = Files::upload($request->favicon,'favicon');
        }
        
        $this->setting->save();


        return Reply::success(__('messages.applicationSetting.settingUpdated'));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
