<?php

namespace App\Notifications;

use App\CompanyPackage;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;

class NewPackageAssign extends Notification
{
    use Queueable;

    /**
     * Create a new notification instance.
     *
     * @return void
     */

    public function __construct(CompanyPackage $companyPackage)
    {
        $this->companyPackages = $companyPackage;

    }

    /**
     * Get the notification's delivery channels.
     *
     * @param  mixed  $notifiable
     * @return array
     */
    public function via($notifiable)
    {
        return ['mail', 'database'];
    }

    /**
     * Get the mail representation of the notification.
     *
     * @param  mixed  $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
        ->subject(__('email.newPackageAssign.subject'))
        ->greeting(__('email.hello') . ' ' . ucwords($notifiable->name) . '!')
        ->line(__('email.newPackageAssign.text'))
        ->line(__('email.newPackageAssign.message', ['package' => $this->companyPackages->package->name . ' (' . $this->companyPackages->package_type . ')']))
        ->line(__('email.thankyouNote'));
    }

    /**
     * Get the array representation of the notification.
     *
     * @param  mixed  $notifiable
     * @return array
     */
    public function toArray($notifiable)
    {
        return $this->companyPackages->toArray();
    }
}
